ExtC

Struct ExtC 

pub struct ExtC {
    pub node: ExtC,
}
Parameter and Modulation Amount Setter API Struct for Node ExtC

Fields

node: ExtC

Implementations

Source

impl ExtC

pub fn slew(self, v: f32, ma: f32) -> ExtC

Set input parameter and modulation amount for Node ExtC Input slew

pub fn atv1(self, v: f32, ma: f32) -> ExtC

Set input parameter and modulation amount for Node ExtC Input atv1

pub fn atv2(self, v: f32, ma: f32) -> ExtC

Set input parameter and modulation amount for Node ExtC Input atv2

pub fn atv3(self, v: f32, ma: f32) -> ExtC

Set input parameter and modulation amount for Node ExtC Input atv3