pub struct Comb { /* private fields */ }Expand description
Build API Struct for Node Comb
Implementations
Sourceimpl Comb
impl Comb
Sourcepub fn set(self) -> Comb
pub fn set(self) -> Comb
Returns a structure with all settable parameters and settings. See also Node Comb
Sourcepub fn set_mod(self) -> Comb
pub fn set_mod(self) -> Comb
Returns a structure with all settable parameters with modulation amount. See also Node Comb