pub struct ExtF { /* private fields */ }Expand description
Build API Struct for Node ExtF
Implementations
Sourceimpl ExtF
impl ExtF
Sourcepub fn set(self) -> ExtF
pub fn set(self) -> ExtF
Returns a structure with all settable parameters and settings. See also Node ExtF
Sourcepub fn set_mod(self) -> ExtF
pub fn set_mod(self) -> ExtF
Returns a structure with all settable parameters with modulation amount. See also Node ExtF