pub struct Inp { /* private fields */ }Expand description
Build API Struct for Node Inp
Implementations
Sourceimpl Inp
impl Inp
Sourcepub fn set(self) -> Inp
pub fn set(self) -> Inp
Returns a structure with all settable parameters and settings. See also Node Inp
Sourcepub fn set_mod(self) -> Inp
pub fn set_mod(self) -> Inp
Returns a structure with all settable parameters with modulation amount. See also Node Inp