pub struct MidiP { /* private fields */ }Expand description
Build API Struct for Node MidiP
Implementations
Sourceimpl MidiP
impl MidiP
Sourcepub fn set(self) -> MidiP
pub fn set(self) -> MidiP
Returns a structure with all settable parameters and settings. See also Node MidiP
Sourcepub fn set_mod(self) -> MidiP
pub fn set_mod(self) -> MidiP
Returns a structure with all settable parameters with modulation amount. See also Node MidiP
Sourcepub fn input(self) -> MidiP
pub fn input(self) -> MidiP
Returns a structure with all input ports/parameters. See also Node MidiP
Sourcepub fn output(&self) -> MidiP
pub fn output(&self) -> MidiP
Returns a structure with all output ports/paramters. See also Node MidiP