NodeContext

Struct NodeContext 

pub struct NodeContext<'a> {
    pub in_connected: u64,
    pub out_connected: u64,
    pub params: &'a [ProcBuf],
}
A context structure that holds temporary information about the currently executed node. This structure is created by the crate::nodes::NodeExecutor on the fly.

Fields

in_connected: u64

The bitmask that indicates which input ports are used/connected to some output.

out_connected: u64

The bitmask that indicates which output ports are used/connected to some input.

params: &'a [ProcBuf]

The node parameters, which are usually not accessed directly.