SyncUnsafeCell

Struct SyncUnsafeCell 

pub struct SyncUnsafeCell<T: ?Sized> { /* private fields */ }

Implementations

Source

impl<T> SyncUnsafeCell<T>

pub fn new(t: T) -> Self

Source

impl<T: ?Sized> SyncUnsafeCell<T>

pub unsafe fn get(&self) -> *mut T

Gets a pointer to a mutable memory cell that is marked being Sync.

Safety

This method is used together with std::sync::Arc in an usually unsafe way to directly get write access to something that is potentially unsafely shared across multiple threads.

In HexoDSP this is used for accessing DspNode state in the audio thread. The architecture of HexoDSP makes sure, that the Arc<SyncUnsafeCell<dyn DspNode>> is only accessed from the audio thread at a given time. Any UI or frontend thread is not going to access these in crate::nodes::NodeConfigurator.